@@ -52,12 +52,13 @@ def cmdline_split(s: str, platform: Union[int, str] = 'this') -> List[str]:
     """  # noqa
     if platform == 'this':
         platform = (sys.platform != 'win32')  # RNC: includes 64-bit Windows
+
     if platform == 1:  # POSIX
         re_cmd_lex = r'''"((?:\\["\\]|[^"])*)"|'([^']*)'|(\\.)|(&&?|\|\|?|\d?\>|[<])|([^\s'"\\&|<>]+)|(\s+)|(.)'''  # noqa
     elif platform == 0:  # Windows/CMD
         re_cmd_lex = r'''"((?:""|\\["\\]|[^"])*)"?()|(\\\\(?=\\*")|\\")|(&&?|\|\|?|\d?>|[<])|([^\s"&|<>]+)|(\s+)|(.)'''  # noqa
     else:
-        raise AssertionError('unknown platform %r' % platform)
+        raise AssertionError(f"unknown platform {platform!r}")
 
     args = []
     accu = None   # collects pieces of one arg
@@ -76,7 +77,9 @@ def cmdline_split(s: str, platform: Union[int, str] = 'this') -> List[str]:
         elif fail:
             raise ValueError("invalid or incomplete shell string")
         elif qs:
-            word = qs.replace('\\"', '"').replace('\\\\', '\\')
+            word = qs.replace(r'\"', '"').replace(r'\\', '\\')
+            # ... raw strings can't end in single backslashes;
+            # https://stackoverflow.com/questions/647769/why-cant-pythons-raw-string-literals-end-with-a-single-backslash  # noqa
             if platform == 0:
                 word = word.replace('""', '"')
         else:
@@ -90,14 +93,64 @@ def cmdline_split(s: str, platform: Union[int, str] = 'this') -> List[str]:
     return args
 
 
-def cmdline_quote(args: List[str]) -> str:
+def cmdline_quote_posix(seq: List[str]) -> str:
+    """
+    Quotes arguments for POSIX, producing a single string suitable for
+    copying/pasting.
+
+    Based on subprocess.list2cmdline().
+    """
+    result = []  # type: List[str]
+    for arg in seq:
+        bs_buf = []  # type: List[str]
+
+        # Add a space to separate this argument from the others
+        if result:
+            result.append(' ')
+
+        # Modified here: quote arguments with "*"
+        needquote = (" " in arg) or ("\t" in arg) or ("*" in arg) or not arg
+        if needquote:
+            result.append('"')
+
+        for c in arg:
+            if c == '\\':
+                # Don't know if we need to double yet.
+                bs_buf.append(c)
+            elif c == '"':
+                # Double backslashes.
+                result.append('\\' * len(bs_buf) * 2)
+                bs_buf = []
+                result.append('\\"')
+            else:
+                # Normal char
+                if bs_buf:
+                    result.extend(bs_buf)
+                    bs_buf = []
+                result.append(c)
+
+        # Add remaining backslashes, if any.
+        if bs_buf:
+            result.extend(bs_buf)
+
+        if needquote:
+            result.extend(bs_buf)
+            result.append('"')
+
+    return ''.join(result)
+
+
+def cmdline_quote(args: List[str], platform: Union[int, str] = 'this') -> str:
     """
     Convert a list of command-line arguments to a suitably quoted command-line
     string that should be copy/pastable into a comand prompt.
     """
-    # if platform == 'this':
-    #     platform = (sys.platform != 'win32')  includes 64-bit Windows
-    # if platform == 1:  # POSIX
-    #     return " ".join(shlex.quote(x) for x in args).replace("\n", r"\n")
-    # elif platform == 0:  # Windows/CMD
-    return subprocess.list2cmdline(args)
+    if platform == 'this':
+        platform = (sys.platform != 'win32')  # RNC: includes 64-bit Windows
+
+    if platform == 1:  # POSIX
+        return cmdline_quote_posix(args)
+    elif platform == 0:  # Windows/CMD
+        return subprocess.list2cmdline(args)
+    else:
+        raise AssertionError(f"unknown platform {platform!r}")
