@@ -168,19 +168,19 @@ def set_null_values_in_dict(d: Dict[str, Any],
 
 
 # noinspection PyPep8
-def map_keys_to_values(l: List[Any], d: Dict[Any, Any], default: Any = None,
+def map_keys_to_values(keys: List[Any], d: Dict[Any, Any], default: Any = None,
                        raise_if_missing: bool = False,
                        omit_if_missing: bool = False) -> List[Any]:
     """
     The ``d`` dictionary contains a ``key -> value`` mapping.
 
-    We start with a list of potential keys in ``l``, and return a list of
+    We start with a list of potential keys in ``keys``, and return a list of
     corresponding values -- substituting ``default`` if any are missing,
     or raising :exc:`KeyError` if ``raise_if_missing`` is true, or omitting the
     entry if ``omit_if_missing`` is true.
     """
     result = []
-    for k in l:
+    for k in keys:
         if raise_if_missing and k not in d:
             raise ValueError("Missing key: " + repr(k))
         if omit_if_missing and k not in d:
